<?php

// include the php library
require_once 'avsPhpSdkV1.php';

// provide the access information, find this credentials in your partner account
$partnerId = 0;
$cipherKey = '';
$hmacKey   = '';

// create a new verification library instance
$avsInstance = new AvsPhpSdkV1(
	$partnerId,
	$cipherKey,
	$hmacKey
);

$avsInstance->setLanguage(AvsPhpSdkV1::LANGUAGE_EN);

// provide required user id (if any)
$demoUserId = 0;

// optional: provide the color config for your implementation
$colorConfigBodyBackground      = '#ffffff';
$colorConfigBodyForeground      = '#000000';
$colorConfigButtonBackground    = '#9acd1f';
$colorConfigButtonForeground    = '#ffffff';
$colorConfigButtonForegroundCTA = '#ffffff';

// provide required user agent
$userAgent = $_SERVER['HTTP_USER_AGENT'];

// provide required website hostname
$websiteHostname = $_SERVER['SERVER_NAME'];

// optional: should the detection process show the detected face or document age in the process or not, boolean
$showDetectedAgeNumber = true;

// provide the required link back, the user will be taken back to this page after the detection process is finisher with success
$linkBack = 'https://example.com';

// provide required user ip
$userIp = $_SERVER['REMOTE_ADDR'];

// optional: provide the user country code
$countryCode = '';
// optional: provide the user state code
$stateCode = '';

// use all the provided data above to create a request object
$avsInstance->fillRequest(
	array(
		'userData'            => array(
			'userId'      => $demoUserId,
			// optional
			'colorConfig' => array(
				'body' => array(
					'background' => $colorConfigBodyBackground,
					'foreground' => $colorConfigBodyForeground,
					'button'     => array(
						'background'             => $colorConfigButtonBackground,
						'foreground'             => $colorConfigButtonForeground,
						'foregroundCallToAction' => $colorConfigButtonForegroundCTA,
					)
				),
			)
		),
		'http'                => array(
			'userAgent'       => $userAgent,
			'websiteHostname' => $websiteHostname,
			'paramList'       => array(
				// optional
				'showDetectedAgeNumber' => $showDetectedAgeNumber
			)
		),
		'verificationVersion' => AvsPhpSdkV1::VERIFICATION_VERSION_IFRAME_V1,
		'linkBack'            => $linkBack,
		'ipStr'               => $userIp,
		// optional
		'countryCode'         => $countryCode,
		'stateCode'           => $stateCode,
	)
);

// encrypt the request object and get the age verification page url
$verificationUrl = $avsInstance->toIframeUrl();

?>
<html>
<head>
	<title>Age verification php sdk demo</title>
</head>
<body>
<style>
body {
	text-align: center;
	font-family: Arial, Helvetica, sans-serif;
}

.container {
	margin: auto;
	width: 800px;
	padding: 30px 10px;
	text-align: left;
}

textarea {
	width: 100%;
}
</style>
<div class="container">
	<h1>Age verification js sdk demo</h1>
	<p>This verification implementation demonstrates the use of the php library paired together with the javascript
		library. By clicking the button below a screen overlay will open with the go.cam age verification page using
		your partner data above. The verification result will be posted back to your verification result callback url if
		it's already defined. Since we are using the javascript implementation, we will also listen to the events we
		receive while the detection it's running and we will log it in the area below.</p>
	<p>
		<button id="openVerificationIframeButton" disabled>Open verification iframe</button>
	</p>
	<p>
		<small>Age verification log:</small>
	</p>
	<p>
		<textarea id="ageVerificationLogsArea" rows="10" readonly></textarea>
	</p>
</div>
<!-- include the js sdk library -->
<script src="avsJsSdkV1.js"></script>

<!-- handle the verification iframe -->
<script>
(function () {

	// define the dom elements we use in the demo
	var openVerificationIframeButton = document.querySelector('#openVerificationIframeButton');
	var ageVerificationLogsArea      = document.querySelector('#ageVerificationLogsArea');

	// define the iframe verification url generated with the php library above
	var iframeUrl = '<?php echo $verificationUrl; ?>';

	// initialize the js sdk config
	AvsJsSdk.V1.Config.create({
		iframeLocationUrl: iframeUrl
	});

	// create a js sdk library instance
	var avsInstance = new AvsJsSdk.V1.Core();

	// initialize the js sdk library
	avsInstance.init();

	// handle the iframe messages
	avsInstance.onMessage = function (eventMessage) {

		switch (eventMessage.name) {

			// check phase: iframe was loaded
			case AvsJsSdk.V1.Config.EVENT_ON_CHECK_IFRAME_LOADED:

				appendToLog('Iframe content was loaded');

				// send an event to the iframe for starting the verification process check phase
				avsInstance.emit(AvsJsSdk.V1.Config.EVENT_STATUS_REQUEST);

				break;

			// check phase: age verification was successful on a previous verification process, user is already verified
			case AvsJsSdk.V1.Config.EVENT_ON_INITIAL_VERIFICATION_SUCCESS:

				appendToLog('Verification already completed, delete the "isAgeVerified" cookie to retry');

				payloadIntegrityCheck(eventMessage.data.payload, function(data) {

					if (data.error) {
						appendToLog(data.error.msg);
						return;
					}

					appendToLog('Cookie payload integrity check success, verification session id: ' + data.sessionId);

				});

				break;

			// check phase: age verification was not successful on a previous verification process or did not run at all
			case AvsJsSdk.V1.Config.EVENT_ON_INITIAL_VERIFICATION_NOT_FOUND:

				// check phase failed, proceed to the verification phase, send an event to start the verification phase resource preload
				avsInstance.emit(AvsJsSdk.V1.Config.EVENT_RESOURCE_PRELOAD);

				appendToLog('Previous verification was not found, initializing the verification phase');

				break;

			// verification phase: verification fatal error, payload was incorrect or resource load failed
			case AvsJsSdk.V1.Config.EVENT_ON_INITIAL_VERIFICATION_FATAL_ERROR:

				appendToLog('Verification fatal error: ' + JSON.stringify(eventMessage.data));

				// TODO: restart the verification process

				break;

			// verification phase: iframe was loaded (resources are still loading)
			case AvsJsSdk.V1.Config.EVENT_ON_START_PAGE_LOADED:

				appendToLog('Resources started loading');

				break;

			// verification phase: iframe resources were loaded
			case AvsJsSdk.V1.Config.EVENT_ON_RESOURCES_LOADED:

				appendToLog('Resources loaded, verification is ready!');

				// enable the "start verification" button
				openVerificationIframeButton.disabled = false;

				// attach an click event to the "start verification" button
				openVerificationIframeButton.addEventListener('click', function () {
					// show the verification iframe as an overlay
					avsInstance.iframeInstance.expand();
				});

				break;

			// verification phase: iframe overlay close button was clicked
			case AvsJsSdk.V1.Config.EVENT_ON_CLOSE_IFRAME:

				// hide the verification iframe overlay (it's still running in the background)
				avsInstance.iframeInstance.collapse();

				appendToLog('Verification iframe closed');

				break;

			// verification phase: verification process was successful
			case AvsJsSdk.V1.Config.EVENT_ON_VERIFICATION_SUCCESS:

				appendToLog('Verification completed successfully');

				// disable the "start verification" button
				openVerificationIframeButton.disabled = true;

				payloadIntegrityCheck(eventMessage.data.payload, function(data) {

					if (data.error) {
						appendToLog(data.error.msg);
						return;
					}

					appendToLog('Cookie payload integrity check success, verification session id: ' + data.sessionId);

				});

				break;

			// verification phase: verification process failed
			case AvsJsSdk.V1.Config.EVENT_ON_VERIFICATION_ERROR:

				appendToLog('Verification completed with error');

				break;

			default:

				// appendToLog('Unhandled event received: ' + eventMessage.name);

		}

	};

	// helper function for the iframe event logs
	var appendToLog = function (message) {
		ageVerificationLogsArea.append(message + "\n");
		ageVerificationLogsArea.scrollTop = ageVerificationLogsArea.scrollHeight;
	}

	// helper function for the payload integrity check
	var payloadIntegrityCheck = function (verificationResultPayload, callback) {

		postAjax(
			'payloadIntegrityCheck.php',
			{
				verificationResultPayload: verificationResultPayload
			},
			function (data) {
				callback(JSON.parse(data));
			}
		);

	}

	// helper function for ajax request
	function postAjax(url, data, success) {
		var params = typeof data == 'string' ? data : Object.keys(data).map(
			function (k) {
				return encodeURIComponent(k) + '=' + encodeURIComponent(data[k])
			}
		).join('&');

		var xhr = window.XMLHttpRequest ? new XMLHttpRequest() : new ActiveXObject("Microsoft.XMLHTTP");
		xhr.open('POST', url);
		xhr.onreadystatechange = function () {
			if (xhr.readyState > 3 && xhr.status == 200) {
				success(xhr.responseText);
			}
		};
		xhr.setRequestHeader('X-Requested-With', 'XMLHttpRequest');
		xhr.setRequestHeader('Content-Type', 'application/x-www-form-urlencoded');
		xhr.send(params);
		return xhr;
	}

})();
</script>
</body>
</html>
